diff --git a/SConstruct b/SConstruct
index b22fa86..7e5884f 100644
--- a/SConstruct
+++ b/SConstruct
@@ -175,14 +175,14 @@ AddOption( "--extrapath",
            type="string",
            nargs=1,
            action="store",
-           help="comma seperated list of add'l paths  (--extrapath /opt/foo/,/foo) static linking" )
+           help="comma separated list of add'l paths  (--extrapath /opt/foo/,/foo) static linking" )
 
 AddOption( "--extrapathdyn",
            dest="extrapathdyn",
            type="string",
            nargs=1,
            action="store",
-           help="comma seperated list of add'l paths  (--extrapath /opt/foo/,/foo) dynamic linking" )
+           help="comma separated list of add'l paths  (--extrapath /opt/foo/,/foo) dynamic linking" )
 
 
 AddOption( "--extralib",
@@ -190,21 +190,21 @@ AddOption( "--extralib",
            type="string",
            nargs=1,
            action="store",
-           help="comma seperated list of libraries  (--extralib js_static,readline" )
+           help="comma separated list of libraries  (--extralib js_static,readline" )
 
 AddOption( "--staticlib",
            dest="staticlib",
            type="string",
            nargs=1,
            action="store",
-           help="comma seperated list of libs to link statically (--staticlib js_static,boost_program_options-mt,..." )
+           help="comma separated list of libs to link statically (--staticlib js_static,boost_program_options-mt,..." )
 
 AddOption( "--staticlibpath",
            dest="staticlibpath",
            type="string",
            nargs=1,
            action="store",
-           help="comma seperated list of dirs to search for staticlib arguments" )
+           help="comma separated list of dirs to search for staticlib arguments" )
 
 AddOption( "--cxx",
            dest="cxx",
diff --git a/s/server.cpp b/s/server.cpp
index 6141816..8becda3 100644
--- a/s/server.cpp
+++ b/s/server.cpp
@@ -91,7 +91,7 @@ namespace mongo {
     };
 
     void sighandler(int sig){
-        dbexit(EXIT_CLEAN, (string("recieved signal ") + BSONObjBuilder::numStr(sig)).c_str());
+        dbexit(EXIT_CLEAN, (string("received signal ") + BSONObjBuilder::numStr(sig)).c_str());
     }
     
     void setupSignals(){
diff --git a/tools/export.cpp b/tools/export.cpp
index aabebf3..612c6d9 100644
--- a/tools/export.cpp
+++ b/tools/export.cpp
@@ -36,7 +36,7 @@ public:
     Export() : Tool( "export" ){
         add_options()
             ("query,q" , po::value<string>() , "query filter, as a JSON string" )
-            ("fields,f" , po::value<string>() , "comma seperated list of field names e.g. -f name,age" )
+            ("fields,f" , po::value<string>() , "comma separated list of field names e.g. -f name,age" )
             ("csv","export to csv instead of json")
             ("out,o", po::value<string>(), "output file; if not specified, stdout is used")
             ;
diff --git a/tools/tool.cpp b/tools/tool.cpp
index c9a2977..2e28e65 100644
--- a/tools/tool.cpp
+++ b/tools/tool.cpp
@@ -216,7 +216,7 @@ namespace mongo {
 
     void Tool::addFieldOptions(){
         add_options()
-            ("fields,f" , po::value<string>() , "comma seperated list of field names e.g. -f name,age" )
+            ("fields,f" , po::value<string>() , "comma separated list of field names e.g. -f name,age" )
             ("fieldFile" , po::value<string>() , "file with fields names - 1 per line" )
             ;
     }

diff --git a/client/syncclusterconnection.h b/client/syncclusterconnection.h
index e3411e1..bd0a78d 100644
--- a/client/syncclusterconnection.h
+++ b/client/syncclusterconnection.h
@@ -28,9 +28,9 @@ namespace mongo {
     class SyncClusterConnection : public DBClientBase {
     public:
         /**
          * @param commaSeperated should be 3 hosts comma seperated
          */
-        SyncClusterConnection( string commaSeperated );
+        SyncClusterConnection( string commaSeparated );
         SyncClusterConnection( string a , string b , string c );
         ~SyncClusterConnection();
         
@@ -28,9 +28,9 @@ namespace mongo {
     public:
         /**
-         * @param commaSeperated should be 3 hosts comma seperated
+         * @param commaSeparated should be 3 hosts comma separated
          */